package com.dhtmlx.connector;

import java.io.IOException;
import java.sql.Connection;
import java.util.HashMap;

import org.json.simple.JSONArray;

public class JSONCommonConnector extends CommonConnector {
	/**
	 * Instantiates a new scheduler connector.
	 * 
	 * @param db the db connection
	 */
	public JSONCommonConnector(Connection db){
		this(db,DBType.Custom);
	}

	/**
	 * Instantiates a new scheduler connector.
	 * 
	 * @param db the db connection
	 * @param db_type the db type
	 */
	public JSONCommonConnector(Connection db, DBType db_type){
		this(db,db_type, new JSONCommonFactory());
	}
	
	/**
	 * Instantiates a new scheduler connector.
	 * 
	 * @param db the db connection
	 * @param db_type the db type
	 * @param a_factory the class factory, which will be used by object
	 */
	public JSONCommonConnector(Connection db, DBType db_type, BaseFactory a_factory){
		super(db,db_type,a_factory);
	}

	@Override
	protected String render_set(ConnectorResultSet result)
			throws ConnectorOperationException {
		JSONArray output = new JSONArray();
		int index = 0;
		HashMap<String,String> values;
		while ( (values = result.get_next()) != null){
			JSONCommonDataItem data = (JSONCommonDataItem)cfactory.createDataItem(values, config, index);
			if (data.get_id()==null)
				data.set_id(uuid());
			
			event.trigger().beforeRender(data);
			data.to_json(output);
			index++;
		}
		return output.toString();
	}
	
	protected String output_as_xml(ConnectorResultSet result) throws ConnectorOperationException{
		String start = "<?xml version='1.0' encoding='"+encoding+"' ?>";
		ConnectorOutputWriter out = new ConnectorOutputWriter(start + xml_start(), render_set(result) + xml_end());
		
		output_as_xml(out.toString());
		return out.toString();
	}	
	
	protected String xml_start(){ return ""; }
	protected String xml_end(){ return ""; }
	
	public void output_as_xml(String data){
		http_response.reset();
		http_response.addHeader("Content-type", "text/javascript;charset=" + encoding);
		
		try {
			java.io.Writer out = http_response.getWriter();
			out.write(data);
			out.close();
			http_response.flushBuffer();
		} catch (IOException e){
			LogManager.getInstance().log("Error during data outputing");
			LogManager.getInstance().log(e.getMessage());
		}
		end_run();
	}
	
}
